@@ -83,7 +83,9 @@ public:
   KProcess fetchNetmask;
   KProcess entries;
   KProcess tcpdump;
+  KProcess stopdump;
   KProcess nmap;
+  KProcess stopmap;
   KProcess addredirect;
   KProcess delredirect;
   KProcess addmangle;
@@ -126,10 +128,12 @@ public slots:
   void probeInterface2(KProcess *, char *, int); 
   void probeInterfaceDone();
   void starttcpDump();
+  void stoptcpDump();
   void closetcpDump();
   void tcpDump();
   void listDump(KProcess *, char *, int);
   void startNMap();
+  void stopNMap();
   void closeNMap();
   void nmapoptActivated(int);
   void nmapoptActivated_icmp(int);
