@@ -43,7 +43,7 @@ struct procfile
  * to make sure all the networking features of the kernel are running
  */
 
-#define NUM_PROC_FILES	11	
+#define NUM_PROC_FILES	19	
 
 procfile pf[NUM_PROC_FILES] = 
 	{
@@ -55,23 +55,39 @@ procfile pf[NUM_PROC_FILES] =
 	 {NULL, "/proc/sys/net/ipv4/ip_dynaddr", "r+", "1",
 		"Could not write to /proc/sys/net/ipv4/ip_dynaddr.\n", 1},
 	 {NULL, "/proc/sys/net/ipv4/icmp_echo_ignore_broadcasts", "r+", "1",
-		"Could not write to /proc/sys/net/ipv4/icmp_echo_ignore_broadcasts.\n",
-	  1 },
+		"Could not write to /proc/sys/net/ipv4/icmp_echo_ignore_broadcasts.\n", 1},
+	 {NULL, "/proc/sys/net/ipv4/icmp_ignore_bogus_error_responses", "r+", "1",
+		"Could not write to /proc/sys/net/ipv4/icmp_ignore_bogus_error_responses.\n", 1},
 	 {NULL, "/proc/sys/net/ipv4/conf/all/secure_redirects", "r+", "1",
-		"Could not write to /proc/sys/net/ipv4/conf/all/secure_redirects.\n",1},	 {NULL, "/proc/sys/net/ipv4/conf/all/send_redirects", "r+", "1",
+		"Could not write to /proc/sys/net/ipv4/conf/all/secure_redirects.\n", 1},	 
+	 {NULL, "/proc/sys/net/ipv4/conf/all/send_redirects", "r+", "1",
 		"Could not write to /proc/sys/net/ipv4/conf/all/send_redirects\n", 1},
 // NEED TO MAKE THIS 1 for tcp_syncookies
 	 {NULL, "/proc/sys/net/ipv4/tcp_syncookies", "r+", "1", 
 		"Could not write to /proc/sys/net/ipv4/tcp_syncookies.\n", 0},
 	 {NULL, "/proc/sys/net/ipv4/conf/all/accept_source_route","r+", "1", 
-		"Could not write to /proc/sys/net/ipv4/conf/all/accept_source_route.\n",
-	  1},
+		"Could not write to /proc/sys/net/ipv4/conf/all/accept_source_route.\n", 1},
 	 {NULL, "/proc/sys/net/ipv4/conf/all/forwarding", "r+", "1",
 		"Could not write to /proc/sys/net/ipv4/conf/all/forwarding.\n", 1},
+	 {NULL, "/proc/sys/net/ipv4/conf/all/log_martians", "r+", "1",
+		"Could not write to /proc/sys/net/ipv4/conf/all/log_martians.\n", 1},
 	 {NULL, "/proc/sys/net/ipv4/conf/all/rp_filter", "r+", "1",
 		"Could not write to /proc/sys/net/ipv4/conf/all/rp_filter.\n", 1},
 	 {NULL, "/proc/sys/net/ipv4/route/max_size", "r+", "65536",
-		"Could not write to /proc/sys/net/ipv4/route/max_size.\n", 1}
+		"Could not write to /proc/sys/net/ipv4/route/max_size.\n", 1},
+// LET'S TRY TO OPTIMIZE BUFFER SIZES
+	 {NULL, "/proc/sys/net/core/optmem_max", "r+", "65536",
+		"Could not write to /proc/sys/net/core/optmem_max.\n", 1},
+	 {NULL, "/proc/sys/net/core/rmem_default", "r+", "262144",
+		"Could not write to /proc/sys/net/core/rmem_default.\n", 1},
+	 {NULL, "/proc/sys/net/core/rmem_max", "r+", "262144",
+		"Could not write to /proc/sys/net/core/rmem_max.\n", 1},
+	 {NULL, "/proc/sys/net/core/wmem_default", "r+", "262144",
+		"Could not write to /proc/sys/net/core/wmem_default.\n", 1},
+	 {NULL, "/proc/sys/net/core/wmem_max", "r+", "262144",
+		"Could not write to /proc/sys/net/core/wmem_max.\n", 1},
+	 {NULL, "/proc/sys/net/core/netdev_max_backlog", "r+", "500",
+		"Could not write to /proc/sys/net/core/netdev_max_backlog.\n", 1}
 	};
 
 
