@@ -1,6 +1,6 @@
   /*
 
-  knetfilter v 2.0.3
+  knetfilter v 2.0.4
 
   Copyright (C) 2000 Luigi Genoni
   		     venom@DarkStar.sns.it
@@ -86,6 +86,44 @@ void knetfilter::startmangleEntries() {
 
 };
 
+
+void knetfilter::starttcpDump() {
+
+  tcpdump.clearArguments();
+  char interfaceChoice2[5]; 
+  strcpy( interfaceChoice2, interfaceChoice );	
+  
+  interfaceChoicedmp = strcat ( interfaceChoice2, interfacenrChoicedmp );
+  
+  //tcpdump << "tcpdump" <<"-c 1000" << "-i" << "eth0" ; 
+  tcpdump << "tcpdump" << "-a" << "-vvv" <<"-c 10000" << "-i" << interfaceChoicedmp ; 
+  
+  
+  bool success=tcpdump.start(KProcess::NotifyOnExit,
+			     KProcess::AllOutput);
+  if (success)
+    statusbar->message(i18n("Running..."), 2000);
+  else
+    statusbar->message(i18n("Couldn't start tcpdump"), 2000);
+  
+};
+
+
+void knetfilter::stoptcpDump() {
+
+  stopdump.clearArguments();
+  stopdump << "killall" << "-9" << "tcpdump" ;
+
+  bool success=stopdump.start(KProcess::NotifyOnExit,
+			     KProcess::AllOutput);
+  if (success)
+    statusbar->message(i18n("Stopping..."),2000);
+  else
+    statusbar->message(i18n("Couldn't stop tcpdump"), 2000);
+
+};
+
+
 void knetfilter::startNMap() {
 
   QString mapaddr, mapnetmask, mapnet;
@@ -151,26 +189,18 @@ void knetfilter::startNMap() {
 };
   
 
+void knetfilter::stopNMap() {
 
-void knetfilter::starttcpDump() {
+  stopmap.clearArguments();
+  stopmap << "killall" << "-9" << "nmap" ;
 
-  tcpdump.clearArguments();
-  char interfaceChoice2[5]; 
-  strcpy( interfaceChoice2, interfaceChoice );	
-  
-  interfaceChoicedmp = strcat ( interfaceChoice2, interfacenrChoicedmp );
-  
-  //tcpdump << "tcpdump" <<"-c 1000" << "-i" << "eth0" ; 
-  tcpdump << "tcpdump" <<"-c 1000" << "-i" << interfaceChoicedmp ; 
-  
-  
-  bool success=tcpdump.start(KProcess::NotifyOnExit,
+  bool success=stopmap.start(KProcess::NotifyOnExit,
 			     KProcess::AllOutput);
   if (success)
-    statusbar->message(i18n("Running..."), 2000);
+    statusbar->message(i18n("Stopping..."),2000);
   else
-    statusbar->message(i18n("Couldn't start tcpdump"), 2000);
-  
+    statusbar->message(i18n("Couldn't stop nmap"), 2000);
+
 };
 
 
@@ -332,6 +362,12 @@ void knetfilter::tcpDump() {
       connect(btnDump,SIGNAL(clicked()), this, SLOT(starttcpDump()));
       grid->addWidget(btnDump,4,1);
         
+      QPushButton *btnStop = new QPushButton(dumpList);
+      btnStop->setText("Stop");
+      btnStop->setFixedHeight(btnStop->sizeHint().height());
+      connect(btnStop,SIGNAL(clicked()), this, SLOT(stoptcpDump()));
+      grid->addWidget(btnStop,4,2);
+        
       QPushButton *btnClose = new QPushButton(dumpList);
       btnClose->setText("Close");
       btnClose->setFixedHeight(btnClose->sizeHint().height());
@@ -411,7 +447,7 @@ void knetfilter::NMap(){
       grid->addMultiCellWidget(labelnmapoptions_icmp,7,7,3,4);
 
       nmapoptions_icmp = new QComboBox ( FALSE, mapList, "nmapoptions_icmp");
-      nmapoptions_icmp->insertItem("Standard ping (-PB = -PI -PT");
+      nmapoptions_icmp->insertItem("Standard ping (-PB = -PI -PT)");
       nmapoptions_icmp->insertItem("ICMP ping (-PI)");
       nmapoptions_icmp->insertItem("TCP ping (-PT)");
       nmapoptions_icmp->insertItem("TCP SYN ping (-PS)");
@@ -425,6 +461,12 @@ void knetfilter::NMap(){
       connect(btnMap,SIGNAL(clicked()), this, SLOT(startNMap()));
       grid->addWidget(btnMap,8,1);
 
+      QPushButton *btnStop = new QPushButton(mapList);
+      btnStop->setText("Stop");
+      btnStop->setFixedHeight(btnStop->sizeHint().height());
+      connect(btnStop,SIGNAL(clicked()), this, SLOT(stopNMap()));
+      grid->addWidget(btnStop,8,2);
+
       QPushButton *btnClose = new QPushButton(mapList);
       btnClose->setText("Close");
       btnClose->setFixedHeight(btnClose->sizeHint().height());
